/* 
 * camera.cc -- camera and methods
 *
 * This file is part of ePiX, a preprocessor for creating high-quality 
 * line figures in LaTeX 
 *
 * Version 0.9.0rc1
 * Last Change: February 03, 2003
 */

/* 
 * Copyright (C) 2001, 2002, 2003
 * Andrew D. Hwang <ahwang@mathcs.holycross.edu>
 * Department of Mathematics and Computer Science
 * College of the Holy Cross
 * Worcester, MA, 01610-2395, USA
 */

/*
 * ePiX is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * ePiX is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with ePiX; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

// n.b. ePiX3d::trig functions are sensitive to current angle units

#include "camera.h"
#include "functions.h"
#include "style.h"

namespace ePiX3d {

  // screen projection mappings ("lenses")

  extern epix3d_camera camera;

  // Point projection to sea-sky plane from point at given "distance"
  // from "target" along "eye" axis
  pair shadow(P arg)
  {
    V arg_vector = carry_to_origin(arg - camera.target);
	
    // get frame coordinates; "|" = dot product
    double u1=camera.orientation.sea()|arg_vector;
    double u2=camera.orientation.sky()|arg_vector;
    double u3=camera.orientation.eye()|arg_vector;

    // if Distance = 0, dist (the reciprocal distance) is also 0
    double dist = Recip(camera.distance);

    return pair(u1/(1+dist*u3), u2/(1+dist*u3));
  }

  pair fisheye(P arg) 
  {
    double d = camera.distance;
    V cam_eye = camera.orientation.eye();
    P camera_location = camera.target + 
      V(camera.target, d*cam_eye.x1(), d*cam_eye.x2(), d*cam_eye.x3());

    // vector from camera to arg, based at camera
    V arg_vector = arg - camera_location;
    double length = norm(arg_vector);

    if (fabs(length) < EPIX_EPSILON)
      return pair(0,0);

    else
      {
	// radially project to sphere of radius d centered at camera
	V temp = (1/length)*arg_vector;
	double u1=camera.orientation.sea()|temp;
	double u2=camera.orientation.sky()|temp;
	//	double u3=-camera.orientation.eye()|temp;
	return pair(u1, u2);
	//	return (std::acos(u3/d)/sqrt(d*d-u3*u3))*pair(u1,u2);
      }
  }

} /* end of namespace */
