/*
 * color.cc -- ePiX color handling
 *
 * This file is part of ePiX, a preprocessor for creating high-quality
 * line figures in LaTeX
 *
 * Version 0.9.0rc1
 *
 * Last Change: February 03, 2003
 */

/*
 * Copyright (C) 2001, 2002, 2003
 * Andrew D. Hwang <ahwang@mathcs.holycross.edu>
 * Department of Mathematics and Computer Science
 * College of the Holy Cross
 * Worcester, MA, 01610-2395, USA
 */
 
/*
 * ePiX is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * ePiX is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with ePiX; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include "functions.h"
#include "style.h"
#include "color.h"
#include "output.h"

namespace ePiX3d {

  extern epix3d_style current;

  void use_rgb(void) { current.color.color_model = RGB; }
  void use_cmyk(void) { current.color.color_model = CMYK; }

  // red-green-blue
  void rgb(double r, double g, double b)
  {
    if ( current.color.color_model == RGB)
      {
	current.color.density_red = clip_to_unit(r);
	current.color.density_green = clip_to_unit(g);
	current.color.density_blue = clip_to_unit(b);
      }
    else
      epix_warning("Attempt to specify RGB color in CMYK color model");
  }

  // cyan-magenta-yellow-black
  void cmyk(double c, double m, double y, double k)
  {
    if ( current.color.color_model == CMYK)
      {
	current.color.density_cyan = clip_to_unit(c);
	current.color.density_magenta = clip_to_unit(m);
	current.color.density_yellow = clip_to_unit(y);
	current.color.density_black = clip_to_unit(k);
      }
    else
      epix_warning("Attempt to specify CMYK color in RGB color model");
  }

  void red(void) { rgb(1,0,0); }
  void green(void) { rgb(0,1,0); }
  void blue(void) { rgb(0,0,1); }
  void white(void) 
    { 
      ( current.color.color_model == RGB ) ? rgb(1,1,1) : cmyk(1,1,1,0); 
    }

  void cyan(void) { cmyk(1,0,0,0); }
  void magenta(void) { cmyk(0,1,0,0); }
  void yellow(void) { cmyk(0,0,1,0); }
  void black(void) { cmyk(0,0,0,1); }

  // primaries with density
  void red(double d) { rgb(d,0,0); }
  void green(double d) { rgb(0,d,0); }
  void blue(double d) { rgb(0,0,d); }

  void cyan(double d) { cmyk(d,0,0,0); }
  void magenta(double d) { cmyk(0,d,0,0); }
  void yellow(double d) { cmyk(0,0,d,0); }

} /* end of namespace */
