/*
 * color.h -- ePiX color handling
 *
 * This file is part of ePiX, a preprocessor for creating high-quality
 * line figures in LaTeX
 *
 * Version 0.9.0rc1
 *
 * Last Change: January 31, 2003
 */

/*
 * Copyright (C) 2001, 2002, 2003
 * Andrew D. Hwang <ahwang@mathcs.holycross.edu>
 * Department of Mathematics and Computer Science
 * College of the Holy Cross
 * Worcester, MA, 01610-2395, USA
 */
 
/*
 * ePiX is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * ePiX is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with ePiX; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */                                                                             
#ifndef _EPIX3d_COLOR
#define _EPIX3d_COLOR

#include <cstdlib>

namespace ePiX3d {

  /*
   * ePiX provides  "pstcol" style colors, which are declarations rather 
   * than delimited environments. To make part of an ePiX file print red 
   * (say), use one of the following:
   *
   *   red();
   *   rgb(1,0,0);
   *
   * rgb and cmyk colors are specified (respectively) by 3 or 4 floats,
   * the densities of the corresponding primary colors. If these densities
   * are specified outside the unit interval [0,1], they will be truncated,
   * e.g., rgb(2, -1, 0.3) = rgb(1, 0, 0.3). 
   *
   * Attempts to specify a CMYK color in RGB mode (or vice versa)
   * generate a warning; no change to the color state is made.
   */

enum COLOR_MODEL {RGB, CMYK};

  // color data
  class color_data {

  public:
    COLOR_MODEL color_model;     //        : RGB
    double density_red;          //        : all 0
    double density_green;
    double density_blue;
    double density_cyan;
    double density_magenta;
    double density_yellow;
    double density_black;

    color_data(void) { color_model = RGB; }
  };

  // red-green-blue
  void use_rgb(void);
  void rgb(double r, double g, double b);

  // cyan-magenta-yellow-black
  void use_cmyk(void);
  void cmyk(double c, double m, double y, double k);

  // primary colors
  void red(void);
  void green(void);
  void blue(void);
  void white(void);

  void cyan(void);
  void magenta(void);
  void yellow(void);
  void black(void);

  // primaries with density
  void red(double d);
  void green(double d);
  void blue(double d);

  void cyan(double d);
  void magenta(double d);
  void yellow(double d);

} /* end of namespace */

#endif /* _EPIX3d_COLOR */
