/*
 * constants.h -- ePiX constants
 *
 * This file is part of ePiX, a preprocessor for creating high-quality
 * line figures in LaTeX
 *
 * Version EPIX_VERSION_NUMBER
 *
 * Last Change: January 31, 2003
 */

/*
 * Copyright (C) 2001, 2002, 2003
 * Andrew D. Hwang <ahwang@mathcs.holycross.edu>
 * Department of Mathematics and Computer Science
 * College of the Holy Cross
 * Worcester, MA, 01610-2395, USA
 */
 
/*
 * ePiX is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * ePiX is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with ePiX; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */                                                                             
#ifndef _EPIX3d_CONSTANTS
#define _EPIX3d_CONSTANTS

#include <cstdlib>

namespace ePiX3d {

  // Compile-time tweakable constants

  // Internal constants
  // ePiX's idea of too small/large (10^\pm 4)
  const double EPIX_EPSILON=0.0001;
  const double EPIX_INFTY=10000.0;

  // fraction of step size when clipping
  const double EPIX_SEEK_SIZE=0.01;

  // Number of steps per point in calculus plots
  const int EPIX_ITERATIONS=200;


  // Output format and appearance
  const int EPIX_NUM_PTS=40;   // Number of points in half-ellipses, splines
  const int EPIX_FILE_WIDTH=70;  // Width of output file, in characters

  // marker diameters in true pt
  const double EPIX_SPOT_DIAM=4;
  const double EPIX_DOT_DIAM=3; 
  const double EPIX_DDOT_DIAM=2;

  const double EPIX_ARROWHEAD_WIDTH=1.5; // Half-width of arrowheads in pt
  const double EPIX_ARROWHEAD_RATIO=5.5; // Aspect ratio of arrowheads

  const double EPIX_PLAIN_WIDTH=0.35; // "\thinlines"
  const double EPIX_BOLD_WIDTH=0.85;  // "\thicklines"

  // Dash length/dot separation parameters
  const double EPIX_DASH_LENGTH=5.0;
  const double EPIX_DOT_SEP=40.0;

  // End of tweakable constants

} /* end of namespace */

#endif /* _EPIX3d_CONSTANTS */
