/* 
 * labels.cc -- Simple picture objects: axes, grids, markers, polygons
 *
 * This file is part of ePiX, a preprocessor for creating high-quality 
 * line figures in LaTeX 
 *
 * Version 0.9.0rc1
 * Last Change: February 07, 2003
 */

/* 
 * Copyright (C) 2001, 2002, 2003
 * Andrew D. Hwang <ahwang@mathcs.holycross.edu>
 * Department of Mathematics and Computer Science
 * College of the Holy Cross
 * Worcester, MA, 01610-2395, USA
 */

/*
 * ePiX is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * ePiX is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with ePiX; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include <iostream>
#include <cstring>
//#include <cstdio>

#include "constants.h"
#include "labels.h"
#include "camera.h"
#include "lengths.h"
#include "output.h"

/*
  extern double h_size, v_size, h_offset, v_offset;
  extern double viewpt1, viewpt2, viewpt3;
  extern double x_min, x_max, y_min, y_max, z_min, z_max;
  extern double x_size, y_size, z_size;
  extern double pic_size;
  extern char *pic_unit;

  extern double epix_stretch_factor;
  // extern int epix_lines_printed;
  extern int EPIX_PATH_STYLE;
*/

namespace ePiX3d {

  using std::cout;

  extern epix3d_camera camera;

  // label -- place test string at location with alignment/offset

  // masked constructors
  label masklabel(P here, pair shift, std::string my_label)
  {
    label temp = label(here, shift, my_label);

    //    temp.base = here;
    //    temp.offset = t2p(shift); // convert true pt to screen coords

    //    temp.alignment = c;
    //    temp.color = current.color;
    temp.masked = true;
    
    //    temp.label_text = my_label;

    return temp;
  }

  label masklabel(P here, std::string my_label)
  {
    label temp = label(here, my_label);
    temp.masked = true;

    return temp;
  }
    
  label masklabel(P here, pair shift, std::string my_label,
		   epix_label_posn my_align)
  {
    label temp = label(here, shift, my_label, my_align);
    temp.masked = true;

    return temp;
  }

  // label printing routines
  /*
    void
    label(P base, P offset, char *label_text)
    {
    P O; // origin
    P temp = c2p(base) + t2p(offset - O);
    fprintf (stdout, "\n\\put(%g,%g){%s}", temp.x1, temp.x2, label_text);
    end_stanza();
    }

    void
    masklabel(P base, P offset, char *label_text)
    {
    P temp = c2p(base) + t2p(offset);
    fprintf (stdout, "\n\\put(%g,%g)", temp.x1, temp.x2);
    fprintf (stdout, "{\\colorbox{white}{%s}}", label_text);
    end_stanza();
    }

    // centered labels
    void
    label(P base, char *label_text)
    {
    fprintf (stdout, "\n\\put(%g,%g){\\makebox(0,0){%s}}", 
    c2p(base).x1, c2p(base).x2, label_text);

    end_stanza();
    }
    void
    masklabel(P base, char *label_text)
    {
    fprintf (stdout, "\n\\put(%g,%g){\\makebox(0,0){\\colorbox{white}{%s}}}", 
    c2p(base).x1, c2p(base).x2, label_text);
  
    end_stanza();
    }

    // labels with LaTeX-style alignment
    void
    label(P base, P offset, char *label_text, const int epix_label_posn)
    {
    P temp = c2p(base) + t2p(offset);
    fprintf (stdout, "\n\\put(%g,%g){\\makebox(0,0)", temp.x1, temp.x2);
    print_epix_label_posn(epix_label_posn);
    fprintf (stdout, "{%s}}", label_text);

    end_stanza();
    }
    void
    masklabel(P base, P offset, char *label_text, const int epix_label_posn)
    {
    P temp = c2p(base) + t2p(offset);
    fprintf (stdout, "\n\\put(%g,%g){\\makebox(0,0)", temp.x1, temp.x2);
    print_epix_label_posn(epix_label_posn);
    fprintf (stdout, "{\\colorbox{white}{%s}}}", label_text);

    end_stanza();
    }
  */

  label marker(P here, epix_mark_type type)
  {
    label temp(here, "");

    switch(type) {

    case CIRC:
      //      double diam = t2p(EPIX_SPOT_DIAM);
      //      temp.label_text = "{\\circle{" + diam + "}}";
      //      sprintf (temp.label_text, "{\\circle{%.3f}}", t2p(EPIX_SPOT_DIAM));
      // kludge to get double in a string
      char label_circ[20];
      sprintf (label_circ, "\\circle{%.3f}", t2p(0.5*EPIX_SPOT_DIAM));
      temp.label_text = label_circ;
      break;

    case SPOT:  
      temp.label_text = "$\\bullet$";
      break;

    case RING:   
      char label_ring[20];
      sprintf (label_ring, "\\circle{%.3f}", t2p(EPIX_SPOT_DIAM));
      temp.label_text = label_ring;
      break;

    case DOT:   
      char label_dot[20];
      sprintf (label_dot, "\\circle*{%.3f}", t2p(EPIX_DOT_DIAM));
      temp.label_text = label_dot;
      break;

    case DDOT:
      char label_ddot[20];
      sprintf (label_ddot, "\\circle*{%.3f}", t2p(EPIX_DDOT_DIAM));
      temp.label_text = label_ddot;
      break;

    case PLUS:
      temp.label_text = "+";
      break;

    case OPLUS:
      temp.label_text = "$\\oplus$";
      break;

    case TIMES:
      temp.label_text = "$\\times$";
      break;

    case OTIMES:
      temp.label_text = "$\\otimes$";
      break;

    case DIAMOND:
      temp.label_text = "$\\diamond$";
      break;

    case UP:
      temp.label_text = "$\\bigtriangleup$";
      break;

    case DOWN:
      temp.label_text = "$\\bigtriangledown$";
      break;

    case BOX:   
      /*
	char label_box[40];
	sprintf (label_box, "\\kern -%dpt \\rule[-%dpt]{%dpt}{%dpt}",
	half_width, half_width, width, width);
      */
      temp.label_text = "\\rule{4pt}{4pt}";
      break;

    case BBOX:   
      temp.label_text = "\\rule{2pt}{2pt}";
      break;

    case H_TICK:   
      temp.label_text = "\\rule{.5pt}{4pt}";
      break;

    case V_TICK:   
      temp.label_text = "\\rule{4pt}{.5pt}";
      break;

    default: 
      break;
    } // end of switch

    return temp;
  }

  label ring(P here, double r)
  {
    label temp(here, "");

    double diam = r/p2t(1.0); // r true pt

    char label_ring[20]; // overflow if diam >= 10pt...
      sprintf (label_ring, "\\circle{%.1f}", diam);
      temp.label_text = label_ring;

      return temp;
  }

  //   static void color_print(void);

  static void print_epix_label_posn(epix_label_posn arg)
    {
      if (arg == c) { cout << "[c]"; }
      else if (arg == t) { cout << "[b]"; }
      else if (arg == tr || arg == rt) { cout << "[bl]"; }
      else if (arg == r) { cout << "[l]"; }
      else if (arg == br || arg == rb) { cout << "[tl]"; }
      else if (arg == b) { cout << "[t]"; }
      else if (arg == bl || arg == lb) { cout << "[tr]"; }
      else if (arg == l) { cout << "[r]"; }
      else if (arg == tl || arg == lt) { cout << "[br]"; }
      else if (arg == no_align) { ; } // do nothing
      else // Just for good measure...
	epix_warning("Unknown label alignment option");
    }

  void print(label arg)
  {
    pair basepoint = c2p(camera.shoot(arg.base)) + t2p(arg.offset);
    /*
      if ( arg.color != current.color )
      color_print();
    */

    cout << "\n\\put" << basepoint << "{\\makebox(0,0)";

    if ( arg.alignment != no_align )
      print_epix_label_posn(arg.alignment);

    if ( arg.masked == true )
      cout << "{\\colorbox{white}{" << arg.label_text << "}}}";
    else
      cout << "{" << arg.label_text << "}}";

  }

  // for label pointers
  void print(label* arg)
  {
    pair basepoint = c2p(camera.shoot(arg->base)) + t2p(arg->offset);

    cout << "\n\\put" << basepoint << "{\\makebox(0,0)";

    if ( arg->alignment != no_align )
      print_epix_label_posn(arg->alignment);

    if ( arg->masked == true )
      cout << "{\\colorbox{white}{" << arg->label_text << "}}}";
    else
      cout << "{" << arg->label_text << "}}";

  }

} /* end of namespace */
