/* 
 * points.cc -- Points and operations
 *
 * This file is part of ePiX, a preprocessor for creating high-quality 
 * line figures in LaTeX 
 *
 * Version 0.9.0rc1
 * Last Change: January 31, 2003
 */

/* 
 * Copyright (C) 2001, 2002, 2003
 * Andrew D. Hwang <ahwang@mathcs.holycross.edu>
 * Department of Mathematics and Computer Science
 * College of the Holy Cross
 * Worcester, MA, 01610-2395, USA
 */

/*
 * ePiX is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * ePiX is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with ePiX; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include <iostream>
#include <math.h>

#include "style.h"
#include "functions.h"
#include "points.h"
#include "vectors.h"
#include "output.h"

namespace ePiX3d {

  // (in)equality
  bool operator == (P arg1, P arg2)
  {
    return ((arg1.x1() == arg2.x1()) && 
	    (arg1.x2() == arg2.x2()) && 
	    (arg1.x3() == arg2.x3()));
  }

  bool operator != (P arg1, P arg2)
  {
    return ((arg1.x1() != arg2.x1()) || 
	    (arg1.x2() != arg2.x2()) ||
	    (arg1.x3() != arg2.x3()));
  }

  // ePiX's concept of finiteness...
  bool is_finite(P arg)
  {
    return ((fabs(arg.x1()) < EPIX_INFTY) &&
	    (fabs(arg.x2()) < EPIX_INFTY) &&
	    (fabs(arg.x3()) < EPIX_INFTY));
  }

  // convex linear combinations
  P midpoint(P arg1, P arg2, double t = 0.5)
  {
    double temp1 = (1-t)*arg1.x1() + t*arg2.x1();
    double temp2 = (1-t)*arg1.x2() + t*arg2.x2();
    double temp3 = (1-t)*arg1.x3() + t*arg2.x3();

    return P(temp1, temp2, temp3);
  }

} /* end of namespace ePiX3d */
