/*
 * style.cc -- ePiX output style data structures and methods
 *
 * This file is part of ePiX, a preprocessor for creating high-quality
 * line figures in LaTeX
 *
 * Version 0.9.0rc1
 * Last Change: February 07, 2003
 *
 */

/*
 * Copyright (C) 2001, 2002, 2003
 * Andrew D. Hwang <ahwang@mathcs.holycross.edu>
 * Department of Mathematics and Computer Science
 * College of the Holy Cross
 * Worcester, MA, 01610-2395, USA
 */
 
/*
 * ePiX is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * ePiX is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with ePiX; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include <iostream>
#include <string>
#include <cstdlib>
#include <math.h>

#include "constants.h"
#include "style.h"
#include "color.h"
#include "functions.h"

namespace ePiX3d {

  extern bool scale_warning;

  extern epix3d_style current;

  // set stretching
  void stretch(double t) { current.stretch_factor = t; }

  // set path width
  void bold(void) { current.line_width = EPIX_BOLD_WIDTH; }
  void endbold(void) { current.line_width = EPIX_PLAIN_WIDTH; }
  void end_bold(void) { current.line_width = EPIX_PLAIN_WIDTH; }
  void plain(void) { current.line_width = EPIX_PLAIN_WIDTH; }

  void pen(double width) { current.line_width = width; }

  void pen(const char* arg)
  {
    char* units;
    double width=strtod(arg, &units);

    if (! strcmp((char *)units,"cm"))
      width *= 72.27/2.54;
 
    else if (! strcmp((char *)units,"in"))
      width *= 72.27;
 
    else if (! strcmp((char *)units,"mm"))
      width *= 72.27/25.4;
    
    else if (! strcmp((char *)units,"pc"))
      width *= 12.0;
 
    else if (! strcmp((char *)units,"pt"))
      ; // do nothing
 
    /* Invalid unit length and no warning printed yet */
    else if (!scale_warning)
      {
	scale_warning = true;
	
	std::cerr << "%% ePiX WARNING: Unrecognized units: " << units
		  << ". Scaling may be incorrect.\n"
		  << "%%   Valid units are "
		  << "\"cm\", \"in\", \"mm\", \"pc\", and \"pt\".\n"
		  << "%%   Please check preamble of source file.\n%%\n";
      }
 
    /* Warning issued already; try our best to comply... */
    else
      ;
  }

  // set path style
  void solid(void)  { current.path_style = SOLID;  }
  void dashed(void) { current.path_style = DASHED; }
  void dotted(void) { current.path_style = DOTTED; }

  // set/get angle units
  void radians(void) { current.angle_multiplier=1.0; }
  void degrees(void) { current.angle_multiplier=M_PI/180; }
  void revolutions(void) { current.angle_multiplier=2*M_PI; }

  double angle_units(void) { return current.angle_multiplier; }

  // shading
  // set gray depth
  void gray(double depth)
  {
    current.gray_depth = clip_to_unit(depth);
  }

  void fill(void) { current.shading = true; }
  void unfill(void) { current.shading = false; }

} /* end of namespace */
