/*
 * style.h -- ePiX output style data structures
 *
 * This file is part of ePiX, a preprocessor for creating high-quality
 * line figures in LaTeX
 *
 * Version 0.9.0rc1
 *
 * Last Change: February 03, 2003
 */

/*
 * Copyright (C) 2001, 2002, 2003
 * Andrew D. Hwang <ahwang@mathcs.holycross.edu>
 * Department of Mathematics and Computer Science
 * College of the Holy Cross
 * Worcester, MA, 01610-2395, USA
 */
 
/*
 * ePiX is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * ePiX is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with ePiX; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */                                                                             
#ifndef _EPIX3d_STYLE
#define _EPIX3d_STYLE

#include <cstdlib>

#include "constants.h"
#include "color.h"

namespace ePiX3d {

  // Path styles, data plot markers, and label alignment types
  enum PATH_STYLE {SOLID, DASHED, DOTTED};
  enum CLIP_STYLE {NONE, SPATIAL, SCREEN, BOTH};

  // coordinate axis tick marks
  enum epix_tick_type {TICK_NULL, H_AXIS, V_AXIS};

  // "vector field"-type objects
  enum epix_field_type {SLOPE, DART, VECTOR};

#ifdef _EPIX_VERSION // We're compiling output.cc
  const char *epix_version="0.9.0rc1"; 
#endif

  // global style data
  class epix3d_style {
  
  public:
    // paths and shading
    PATH_STYLE path_style;       //        : SOLID
    CLIP_STYLE clip_style;       //        : NONE
    double line_width;           //        : 0.35 (plain)
    double stretch_factor;       //        : 1.0
    double angle_multiplier;     //        : 1.0 (radians)
    double gray_depth;           //        : 0. fill color; 0=white, 1=black
    // all false by default
    bool shading; // shade closed paths
    bool amalgamating; // amalgamate path objects
    bool hidden_line_removal; // not yet implemented

    color_data color;

    // initial state
    epix3d_style(void)
      {
	path_style = SOLID;
	clip_style = NONE;
	line_width = EPIX_PLAIN_WIDTH;
	stretch_factor = 1.0;
	gray_depth = 0;
	angle_multiplier = 1.0;
	shading = false;
	amalgamating = false;
	hidden_line_removal = false; // not yet implemented

	color = color_data();
      } // end of constructor

  }; /* end of class epix3d_style */

  // set stretch factor
  void stretch(double t);

  // set path width
  void pen(double width);
  void pen(const char* arg);
  void bold(void);
  void endbold(void);
  void end_bold(void);
  void plain(void);

  // set path style
  void solid(void);
  void dashed(void);
  void dotted(void);

  // set/get angle units
  void radians(void);
  void degrees(void);
  void revolutions(void);
  double angle_units(void);

  // set gray depth
  void gray(double depth);
  void fill(void);
  void unfill(void);

} /* end of namespace */

#endif /* _EPIX3d_STYLE */
